Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(321)

Unified Diff: webkit/plugins/ppapi/host_var_tracker.cc

Issue 10542150: Actually free plugin implement vars when running out of process when the (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « webkit/plugins/ppapi/host_var_tracker.h ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webkit/plugins/ppapi/host_var_tracker.cc
===================================================================
--- webkit/plugins/ppapi/host_var_tracker.cc (revision 141525)
+++ webkit/plugins/ppapi/host_var_tracker.cc (working copy)
@@ -100,7 +100,7 @@
return static_cast<int>(found->second->size());
}
-void HostVarTracker::ForceFreeNPObjectsForInstance(PP_Instance instance) {
+void HostVarTracker::DidDeleteInstance(PP_Instance instance) {
DCHECK(CalledOnValidThread());
InstanceMap::iterator found_instance = instance_map_.find(instance);
@@ -130,8 +130,8 @@
void HostVarTracker::ForceReleaseNPObject(
const base::WeakPtr< ::ppapi::NPObjectVar>& object) {
// There's a chance that the object was already deleted before we got here.
// See ForceFreeNPObjectsForInstance for further explanation. If the object
// was deleted, the WeakPtr will return NULL.
if (!object.get())
return;
object->InstanceDeleted();
@@ -130,8 +130,8 @@
const base::WeakPtr< ::ppapi::NPObjectVar>& object) {
// There's a chance that the object was already deleted before we got here.
- // See ForceFreeNPObjectsForInstance for further explanation. If the object
- // was deleted, the WeakPtr will return NULL.
+ // See DidDeleteInstance for further explanation. If the object was deleted,
+ // the WeakPtr will return NULL.
if (!object.get())
return;
« no previous file with comments | « webkit/plugins/ppapi/host_var_tracker.h ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698